@@ -27,7 +27,7 @@ class Certificate(BrowserView):
     @property
     @memoize
     def country_adapter(self):
-        """ Try to get a specific adapter for this country
+        """Try to get a specific adapter for this country
         that will be used to show and handle additional fields in the certificate
 
         The adapter should be a view like @@certificate_fr_specific
@@ -44,11 +44,13 @@ class Certificate(BrowserView):
     @property
     @memoize
     def known_field_names(self):
-        """ Return the field names we expect to have in the form
+        """Return the field names we expect to have in the form
 
         By default we expect to have a title
         """
-        return ("title",) + getattr(self.country_adapter, "extra_known_field_names", ())
+        return ("title", "company_identification_number") + getattr(
+            self.country_adapter, "extra_known_field_names", ()
+        )
 
     @property
     @memoize
@@ -58,8 +60,7 @@ class Certificate(BrowserView):
     @property
     @memoize
     def country(self):
-        """ The country inside /sectors that contains the certificates configuration
-        """
+        """The country inside /sectors that contains the certificates configuration"""
         return api.portal.get().sectors[self.webhelpers.country]
 
     @property
@@ -70,13 +71,11 @@ class Certificate(BrowserView):
     @property
     @memoize
     def completion_percentage(self):
-        """ Report how much of the session the user has completed
-        """
+        """Report how much of the session the user has completed"""
         return self.webhelpers.traversed_session.session.completion_percentage or 0
 
     def can_display_certificate_notice(self):
-        """ Condition to show the certificate yellow box below the pie chart
-        """
+        """Condition to show the certificate yellow box below the pie chart"""
         country = self.country
         return (
             getattr(country, "certificates_enabled", False)
@@ -84,8 +83,7 @@ class Certificate(BrowserView):
         )
 
     def can_display_certificate_teaser(self):
-        """ Condition to show the invite for the user to earn the certificate
-        """
+        """Condition to show the invite for the user to earn the certificate"""
         country = self.country
         return (
             getattr(country, "certificates_enabled", False)
@@ -95,8 +93,7 @@ class Certificate(BrowserView):
         )
 
     def can_display_certificate_earned(self):
-        """ Condition to show the link to the certificate view
-        """
+        """Condition to show the link to the certificate view"""
         country = self.country
         return (
             getattr(country, "certificates_enabled", False)
@@ -106,8 +103,7 @@ class Certificate(BrowserView):
     @property
     @memoize
     def certificate(self):
-        """ Find the certificate associated to this session
-        """
+        """Find the certificate associated to this session"""
         return (
             Session.query(model.Certificate)
             .filter(model.Certificate.session_id == self.webhelpers.session_id)
@@ -117,10 +113,12 @@ class Certificate(BrowserView):
     @property
     @memoize
     def session(self):
-        """ Find the certificate associated to this session
-        """
         return self.webhelpers.traversed_session.session
 
+    @property
+    def session_url(self):
+        return self.webhelpers.traversed_session.absolute_url()
+
     @property
     @memoize
     def certificate_json(self):
@@ -157,8 +155,7 @@ class Certificate(BrowserView):
 
 @implementer(IPublishTraverse)
 class PublicCertificate(BrowserView):
-    """ View to publish a public certificate once the hash is known
-    """
+    """View to publish a public certificate once the hash is known"""
 
     def publishTraverse(self, request, name):
         self.secret = name
@@ -177,8 +174,7 @@ class PublicCertificate(BrowserView):
     @property
     @memoize
     def session(self):
-        """ Find the certificate associated to this session
-        """
+        """Find the certificate associated to this session"""
         return self.certificate.session
 
     @property
@@ -186,7 +182,7 @@ class PublicCertificate(BrowserView):
     def survey(self):
         try:
             return self.context.restrictedTraverse(str(self.session.zodb_path))
-        except:
+        except Exception:
             return None
 
     @property
@@ -207,7 +203,7 @@ class PublicCertificate(BrowserView):
     @property
     @memoize
     def country_adapter(self):
-        """ Try to get a specific adapter for this country
+        """Try to get a specific adapter for this country
         that will be used to show and handle additional fields in the certificate
 
         The adapter should be a view like @@certificate_fr_specific
